==> qbittorrent_4.1.5.1+rb2.orig.tar.xz: qbittorrent-4.1.5.1+rb2/src/gui/hidabletabwidget.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2006  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef HIDABLETABWIDGET_H
#define HIDABLETABWIDGET_H

#include <QTabBar>
#include <QTabWidget>

#ifdef Q_OS_MAC
#include <QStyle>
#endif

class HidableTabWidget : public QTabWidget
{
public:
    explicit HidableTabWidget(QWidget *parent = nullptr)
        : QTabWidget(parent)
    {
    }

protected:
#ifdef Q_OS_MAC
    void paintEvent(QPaintEvent *event) override
    {
        // Hide the pane for macintosh style
        if (!style()->inherits("QMacStyle"))
            QTabWidget::paintEvent(event);
    }
#endif

    void tabInserted(int index) override
    {
        QTabWidget::tabInserted(index);
        tabBar()->setVisible(count() != 1);
    }

    void tabRemoved(int index) override
    {
        //QTabWidget::tabInserted(index);
        QTabWidget::tabRemoved(index);
        tabBar()->setVisible(count() != 1);
    }
};

#endif // HIDABLETABWIDGET_H

==> qbittorrent_4.2.5.orig.tar.xz: qbittorrent-4.2.5/src/gui/hidabletabwidget.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2006  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef HIDABLETABWIDGET_H
#define HIDABLETABWIDGET_H

#include <QTabWidget>

#ifdef Q_OS_MACOS
class QPaintEvent;
#endif

class HidableTabWidget final : public QTabWidget
{
public:
    explicit HidableTabWidget(QWidget *parent = nullptr);

private:
    void tabInserted(int index) override;
    void tabRemoved(int index) override;

#ifdef Q_OS_MACOS
    void paintEvent(QPaintEvent *event) override;
#endif
};

#endif // HIDABLETABWIDGET_H
